@@ -92,8 +92,40 @@ class Overseerr(object):
         return
 
     def get_poster_url(self, path):
-        return ("https://image.tmdb.org/t/p/w300_and_h450_bestv2" + path)
+        return ("https://image.tmdb.org/t/p/w600_and_h900_bestv2" + path)
 
+    def create_request_object(self, request):
+        tmdb_id = request["media"]["tmdbId"]
+        if tmdb_id is not None:
+
+            return_array = {
+                    "last_request_id": request["id"],
+                    "last_request_status": request["status"],
+                    "last_request_created": request["createdAt"],
+                    "last_request_type": request["type"],
+                    "last_request_username": request["requestedBy"]["username"]
+            }
+
+            if request["type"] == "tv":
+                tv_data = self._request_connection(f"tv/{tmdb_id}").json()
+                return_array.update({
+                    "last_request_title": tv_data["name"],
+                    "last_request_poster": self.get_poster_url(tv_data["posterPath"]),
+                    "last_request_num_seasons": self.tv_get_total_num_seasons(request),
+                    "last_request_total_seasons": self.tv_get_total_num_seasons(tv_data),
+                    "last_request_all_seasons": self.tv_is_all_seasons(tv_data, request),
+                    "last_request_episode_count": self.tv_get_requested_episode_count(tv_data, request),
+                })
+
+            if request["type"] == "movie":
+                movie_data = self._request_connection(f"movie/{tmdb_id}").json()
+                return_array.update({                  
+                    "last_request_title": movie_data["title"],
+                    "last_request_poster": self.get_poster_url(movie_data["posterPath"]),
+                })
+            return return_array
+        return None
+                
     def request_movie(self, movie_id):
         data = {
             "mediaType": "movie",
@@ -139,6 +171,33 @@ class Overseerr(object):
         print(data)
         request(lambda: self._request_connection(path="request", post_data=data))
 
+    def tv_get_total_num_seasons(self, tv_data):
+        i = 0
+        for season in tv_data["seasons"]:
+            if season["seasonNumber"] == 0:
+                continue
+            i += 1
+        return i
+
+    def tv_is_all_seasons(self, tv_data, request):
+        num_seasons = self.tv_get_total_num_seasons(tv_data)
+        num_requested_seasons = self.tv_get_total_num_seasons(request)
+        if (num_seasons == num_requested_seasons):
+           return True
+        return False
+
+    def tv_get_requested_episode_count(self, tv_data, request):
+        i = 0
+        for season in request["seasons"]:
+            if season["seasonNumber"] == 0:
+                continue
+            for tv_season in tv_data["seasons"]:
+                if tv_season["seasonNumber"] == season["seasonNumber"]:
+                    i += tv_season["episodeCount"]
+                    break
+        return i
+        
+
     def request_music(self, album_id):
         # data = {"foreignAlbumId": album_id}
         # request(lambda: self._request_connection(path="Request/music", post_data=data))
@@ -159,20 +218,7 @@ class Overseerr(object):
         tmdb_id = None
         for request in requests:
             if request["type"] == "movie":
-                tmdb_id = request["media"]["tmdbId"]
-                break
-
-        if tmdb_id is not None:
-            movie_data = self._request_connection(f"movie/{tmdb_id}").json()
-            return {
-                "last_request_id": request["id"],
-                "last_request_status": request["status"],
-                "last_request_created": request["createdAt"],
-                "last_request_title": movie_data["title"],
-                "last_request_poster": self.get_poster_url(movie_data["posterPath"]),
-                "last_request_type": request["type"],
-                "last_request_username": request["requestedBy"]["username"],
-            }
+                return self.create_request_object(request)      
         return None
 
     @property
@@ -181,22 +227,9 @@ class Overseerr(object):
         tmdb_id = None
         for request in requests:
             if request["type"] == "tv":
-                tmdb_id = request["media"]["tmdbId"]
-                break
-
-        if tmdb_id is not None:
-            tv_data = self._request_connection(f"tv/{tmdb_id}").json()
-            return {
-                "last_request_id": request["id"],
-                "last_request_status": request["status"],
-                "last_request_created": request["createdAt"],
-                "last_request_title": tv_data["name"],
-                "last_request_poster": self.get_poster_url(tv_data["posterPath"]),
-                "last_request_type": request["type"],
-                "last_request_username": request["requestedBy"]["username"],
-            }
-
-        return None
+                return self.create_request_object(request)
+        return None        
+      
 
     @property
     def tv_requests(self):
@@ -228,72 +261,17 @@ class Overseerr(object):
     @property
     def last_pending_request(self):
         requests = self._request_connection("Request?filter=pending").json()["results"]
-        tmdb_id = None
         for request in requests:
-            tmdb_id = request["media"]["tmdbId"]
-            break
-
-        if tmdb_id is not None:
-            if request["type"] == "tv":
-                tv_data = self._request_connection(f"tv/{tmdb_id}").json()
-                return {
-                    "last_request_id": request["id"],
-                    "last_request_status": request["status"],
-                    "last_request_created": request["createdAt"],
-                    "last_request_title": tv_data["name"],
-                    "last_request_poster": self.get_poster_url(tv_data["posterPath"]),
-                    "last_request_type": request["type"],
-                    "last_request_username": request["requestedBy"]["username"],
-                }
-
-            if request["type"] == "movie":
-                movie_data = self._request_connection(f"movie/{tmdb_id}").json()
-                return {
-                    "last_request_id": request["id"],
-                    "last_request_status": request["status"],
-                    "last_request_created": request["createdAt"],
-                    "last_request_title": movie_data["title"],
-                    "last_request_poster": self.get_poster_url(movie_data["posterPath"]),
-                    "last_request_type": request["type"],
-                    "last_request_username": request["requestedBy"]["username"],
-                }
-
+            return self.create_request_object(request)
         return None
-
+     
     @property
     def last_total_request(self):
         requests = self._request_connection("Request").json()["results"]
         tmdb_id = None
         for request in requests:
-            tmdb_id = request["media"]["tmdbId"]
-            break
-
-        if tmdb_id is not None:
-            if request["type"] == "tv":
-                tv_data = self._request_connection(f"tv/{tmdb_id}").json()
-                return {
-                    "last_request_id": request["id"],
-                    "last_request_status": request["status"],
-                    "last_request_created": request["createdAt"],
-                    "last_request_title": tv_data["name"],
-                    "last_request_poster": self.get_poster_url(tv_data["posterPath"]),
-                    "last_request_type": request["type"],
-                    "last_request_username": request["requestedBy"]["username"],
-                }
-
-            if request["type"] == "movie":
-                movie_data = self._request_connection(f"movie/{tmdb_id}").json()
-                return {
-                    "last_request_id": request["id"],
-                    "last_request_status": request["status"],
-                    "last_request_created": request["createdAt"],
-                    "last_request_title": movie_data["title"],
-                    "last_request_poster": self.get_poster_url(movie_data["posterPath"]),
-                    "last_request_type": request["type"],
-                    "last_request_username": request["requestedBy"]["username"],
-                }
-
-        return None
+            return self.create_request_object(request)
+        return None        
 
     @property
     def approved_requests(self):
